compute_approval_hash

Function compute_approval_hash 

pub fn compute_approval_hash(hooks: Option<&Hooks>) -> String
Compute a hash for approval based only on security-sensitive hooks.

Only onEnter, onExit, and prePush hooks are included since they execute arbitrary commands. Changes to env vars, tasks, config settings do NOT require re-approval.